# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/ref.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/common_config/ref.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"+\n\x12ServiceTemplateRef\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_SERVICETEMPLATEREF = DESCRIPTOR.message_types_by_name['ServiceTemplateRef']
ServiceTemplateRef = _reflection.GeneratedProtocolMessageType('ServiceTemplateRef', (_message.Message,), {
  'DESCRIPTOR' : _SERVICETEMPLATEREF,
  '__module__' : 'prodvana.common_config.ref_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ServiceTemplateRef)
  })
_sym_db.RegisterMessage(ServiceTemplateRef)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _SERVICETEMPLATEREF.fields_by_name['name']._options = None
  _SERVICETEMPLATEREF.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICETEMPLATEREF._serialized_start=85
  _SERVICETEMPLATEREF._serialized_end=128
# @@protoc_insertion_point(module_scope)
