# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/parameters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/common_config/parameters.proto\x12\x16prodvana.common_config\x1a$prodvana/common_config/program.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\"&\n\rProgramChange\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"2\n\x19StringParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"\xc3\x02\n\x1e\x44ockerImageParameterDefinition\x12\x1c\n\x0b\x64\x65\x66\x61ult_tag\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12P\n\x13image_registry_info\x18\x02 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfoB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12^\n\x07\x63hanges\x18\x03 \x03(\x0b\x32>.prodvana.common_config.DockerImageParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1aQ\n\x07\x43hanges\x12\x38\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x14\n\x12\x46ixedReplicaChange\"\xe5\x01\n\x16IntParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12V\n\x07\x63hanges\x18\x02 \x03(\x0b\x32\x36.prodvana.common_config.IntParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1a\\\n\x07\x43hanges\x12\x43\n\rfixed_replica\x18\x01 \x01(\x0b\x32*.prodvana.common_config.FixedReplicaChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x1b\n\x19SecretParameterDefinition\"\x81\x03\n\x13ParameterDefinition\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x43\n\x06string\x18\x03 \x01(\x0b\x32\x31.prodvana.common_config.StringParameterDefinitionH\x00\x12N\n\x0c\x64ocker_image\x18\x04 \x01(\x0b\x32\x36.prodvana.common_config.DockerImageParameterDefinitionH\x00\x12=\n\x03int\x18\x05 \x01(\x0b\x32..prodvana.common_config.IntParameterDefinitionH\x00\x12\x43\n\x06secret\x18\x06 \x01(\x0b\x32\x31.prodvana.common_config.SecretParameterDefinitionH\x00\x12\x10\n\x08required\x18\x07 \x01(\x08\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\"w\n\x14SecretParameterValue\x12\x14\n\nraw_secret\x18\x01 \x01(\tH\x00\x12\x34\n\nsecret_ref\x18\x02 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x13\n\x0csecret_oneof\x12\x03\xf8\x42\x01\"\xcc\x01\n\x0eParameterValue\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x12\r\n\x03int\x18\x04 \x01(\x03H\x00\x12\x1a\n\x10\x64ocker_image_tag\x18\x05 \x01(\tH\x00\x12>\n\x06secret\x18\x06 \x01(\x0b\x32,.prodvana.common_config.SecretParameterValueH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04R\x0c\x64ocker_image\"b\n\x10ParametersConfig\x12N\n\nparameters\x18\x01 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_PROGRAMCHANGE = DESCRIPTOR.message_types_by_name['ProgramChange']
_STRINGPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['StringParameterDefinition']
_DOCKERIMAGEPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['DockerImageParameterDefinition']
_DOCKERIMAGEPARAMETERDEFINITION_CHANGES = _DOCKERIMAGEPARAMETERDEFINITION.nested_types_by_name['Changes']
_FIXEDREPLICACHANGE = DESCRIPTOR.message_types_by_name['FixedReplicaChange']
_INTPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['IntParameterDefinition']
_INTPARAMETERDEFINITION_CHANGES = _INTPARAMETERDEFINITION.nested_types_by_name['Changes']
_SECRETPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['SecretParameterDefinition']
_PARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['ParameterDefinition']
_SECRETPARAMETERVALUE = DESCRIPTOR.message_types_by_name['SecretParameterValue']
_PARAMETERVALUE = DESCRIPTOR.message_types_by_name['ParameterValue']
_PARAMETERSCONFIG = DESCRIPTOR.message_types_by_name['ParametersConfig']
ProgramChange = _reflection.GeneratedProtocolMessageType('ProgramChange', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMCHANGE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ProgramChange)
  })
_sym_db.RegisterMessage(ProgramChange)

StringParameterDefinition = _reflection.GeneratedProtocolMessageType('StringParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _STRINGPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.StringParameterDefinition)
  })
_sym_db.RegisterMessage(StringParameterDefinition)

DockerImageParameterDefinition = _reflection.GeneratedProtocolMessageType('DockerImageParameterDefinition', (_message.Message,), {

  'Changes' : _reflection.GeneratedProtocolMessageType('Changes', (_message.Message,), {
    'DESCRIPTOR' : _DOCKERIMAGEPARAMETERDEFINITION_CHANGES,
    '__module__' : 'prodvana.common_config.parameters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.DockerImageParameterDefinition.Changes)
    })
  ,
  'DESCRIPTOR' : _DOCKERIMAGEPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.DockerImageParameterDefinition)
  })
_sym_db.RegisterMessage(DockerImageParameterDefinition)
_sym_db.RegisterMessage(DockerImageParameterDefinition.Changes)

FixedReplicaChange = _reflection.GeneratedProtocolMessageType('FixedReplicaChange', (_message.Message,), {
  'DESCRIPTOR' : _FIXEDREPLICACHANGE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.FixedReplicaChange)
  })
_sym_db.RegisterMessage(FixedReplicaChange)

IntParameterDefinition = _reflection.GeneratedProtocolMessageType('IntParameterDefinition', (_message.Message,), {

  'Changes' : _reflection.GeneratedProtocolMessageType('Changes', (_message.Message,), {
    'DESCRIPTOR' : _INTPARAMETERDEFINITION_CHANGES,
    '__module__' : 'prodvana.common_config.parameters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.IntParameterDefinition.Changes)
    })
  ,
  'DESCRIPTOR' : _INTPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.IntParameterDefinition)
  })
_sym_db.RegisterMessage(IntParameterDefinition)
_sym_db.RegisterMessage(IntParameterDefinition.Changes)

SecretParameterDefinition = _reflection.GeneratedProtocolMessageType('SecretParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _SECRETPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.SecretParameterDefinition)
  })
_sym_db.RegisterMessage(SecretParameterDefinition)

ParameterDefinition = _reflection.GeneratedProtocolMessageType('ParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParameterDefinition)
  })
_sym_db.RegisterMessage(ParameterDefinition)

SecretParameterValue = _reflection.GeneratedProtocolMessageType('SecretParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _SECRETPARAMETERVALUE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.SecretParameterValue)
  })
_sym_db.RegisterMessage(SecretParameterValue)

ParameterValue = _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERVALUE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParameterValue)
  })
_sym_db.RegisterMessage(ParameterValue)

ParametersConfig = _reflection.GeneratedProtocolMessageType('ParametersConfig', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERSCONFIG,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParametersConfig)
  })
_sym_db.RegisterMessage(ParametersConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _PROGRAMCHANGE.fields_by_name['name']._options = None
  _PROGRAMCHANGE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['default_tag']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['default_tag']._serialized_options = b'\372B\004r\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _INTPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _INTPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._options = None
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _PARAMETERDEFINITION.fields_by_name['name']._options = None
  _PARAMETERDEFINITION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._options = None
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._options = None
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.fields_by_name['name']._options = None
  _PARAMETERVALUE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PARAMETERSCONFIG.fields_by_name['parameters']._options = None
  _PARAMETERSCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PROGRAMCHANGE._serialized_start=164
  _PROGRAMCHANGE._serialized_end=202
  _STRINGPARAMETERDEFINITION._serialized_start=204
  _STRINGPARAMETERDEFINITION._serialized_end=254
  _DOCKERIMAGEPARAMETERDEFINITION._serialized_start=257
  _DOCKERIMAGEPARAMETERDEFINITION._serialized_end=580
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES._serialized_start=499
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES._serialized_end=580
  _FIXEDREPLICACHANGE._serialized_start=582
  _FIXEDREPLICACHANGE._serialized_end=602
  _INTPARAMETERDEFINITION._serialized_start=605
  _INTPARAMETERDEFINITION._serialized_end=834
  _INTPARAMETERDEFINITION_CHANGES._serialized_start=742
  _INTPARAMETERDEFINITION_CHANGES._serialized_end=834
  _SECRETPARAMETERDEFINITION._serialized_start=836
  _SECRETPARAMETERDEFINITION._serialized_end=863
  _PARAMETERDEFINITION._serialized_start=866
  _PARAMETERDEFINITION._serialized_end=1251
  _SECRETPARAMETERVALUE._serialized_start=1253
  _SECRETPARAMETERVALUE._serialized_end=1372
  _PARAMETERVALUE._serialized_start=1375
  _PARAMETERVALUE._serialized_end=1579
  _PARAMETERSCONFIG._serialized_start=1581
  _PARAMETERSCONFIG._serialized_end=1679
# @@protoc_insertion_point(module_scope)
