# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/env.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/common_config/env.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"w\n\x08\x45nvValue\x12\x0f\n\x05value\x18\x01 \x01(\tH\x00\x12\x14\n\nraw_secret\x18\x02 \x01(\tH\x00\x12\x30\n\x06secret\x18\x03 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01\"8\n\x06Secret\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07version\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_ENVVALUE = DESCRIPTOR.message_types_by_name['EnvValue']
_SECRET = DESCRIPTOR.message_types_by_name['Secret']
EnvValue = _reflection.GeneratedProtocolMessageType('EnvValue', (_message.Message,), {
  'DESCRIPTOR' : _ENVVALUE,
  '__module__' : 'prodvana.common_config.env_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.EnvValue)
  })
_sym_db.RegisterMessage(EnvValue)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'prodvana.common_config.env_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.Secret)
  })
_sym_db.RegisterMessage(Secret)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _ENVVALUE.oneofs_by_name['value_oneof']._options = None
  _ENVVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _SECRET.fields_by_name['key']._options = None
  _SECRET.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SECRET.fields_by_name['version']._options = None
  _SECRET.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _ENVVALUE._serialized_start=85
  _ENVVALUE._serialized_end=204
  _SECRET._serialized_start=206
  _SECRET._serialized_end=262
# @@protoc_insertion_point(module_scope)
