# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/common_config/notification.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"x\n\x12NotificationConfig\x12?\n\x05slack\x18\x01 \x01(\x0b\x32\x30.prodvana.common_config.NotificationConfig.Slack\x1a!\n\x05Slack\x12\x18\n\x07\x63hannel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_NOTIFICATIONCONFIG = DESCRIPTOR.message_types_by_name['NotificationConfig']
_NOTIFICATIONCONFIG_SLACK = _NOTIFICATIONCONFIG.nested_types_by_name['Slack']
NotificationConfig = _reflection.GeneratedProtocolMessageType('NotificationConfig', (_message.Message,), {

  'Slack' : _reflection.GeneratedProtocolMessageType('Slack', (_message.Message,), {
    'DESCRIPTOR' : _NOTIFICATIONCONFIG_SLACK,
    '__module__' : 'prodvana.common_config.notification_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.NotificationConfig.Slack)
    })
  ,
  'DESCRIPTOR' : _NOTIFICATIONCONFIG,
  '__module__' : 'prodvana.common_config.notification_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.NotificationConfig)
  })
_sym_db.RegisterMessage(NotificationConfig)
_sym_db.RegisterMessage(NotificationConfig.Slack)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _NOTIFICATIONCONFIG_SLACK.fields_by_name['channel']._options = None
  _NOTIFICATIONCONFIG_SLACK.fields_by_name['channel']._serialized_options = b'\372B\004r\002\020\001'
  _NOTIFICATIONCONFIG._serialized_start=94
  _NOTIFICATIONCONFIG._serialized_end=214
  _NOTIFICATIONCONFIG_SLACK._serialized_start=181
  _NOTIFICATIONCONFIG_SLACK._serialized_end=214
# @@protoc_insertion_point(module_scope)
