# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/service_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.service import parameters_pb2 as prodvana_dot_service_dot_parameters__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2
from prodvana.proto.prodvana.service import object_pb2 as prodvana_dot_service_dot_object__pb2
from prodvana.proto.prodvana.stat import efficiency_pb2 as prodvana_dot_stat_dot_efficiency__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/service/service_manager.proto\x12\x10prodvana.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'prodvana/common_config/parameters.proto\x1a!prodvana/service/parameters.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\x1a\x1dprodvana/service/object.proto\x1a\x1eprodvana/stat/efficiency.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a prodvana/insights/insights.proto\x1a\x18prodvana/repo/repo.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"w\n\x1dServiceConfigVersionReference\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x16service_config_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xb5\x05\n\x12\x41pplyParametersReq\x12\x39\n\x0eservice_config\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigH\x00\x12Q\n\x16service_config_version\x18\x08 \x01(\x0b\x32/.prodvana.service.ServiceConfigVersionReferenceH\x00\x12I\n\nparameters\x18\t \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\n \x03(\x0b\x32\x36.prodvana.service.ApplyParametersReq.PerReleaseChannelB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12%\n\x1dtest_only_skip_registry_check\x18\x04 \x01(\x08\x12\x13\n\x0b\x61pplication\x18\x05 \x01(\t\x12(\n\x06source\x18\x06 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x07 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x1a\x80\x01\n\x11PerReleaseChannel\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12I\n\nparameters\x18\x02 \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x10release_channelsR\x12\x63ompute_efficiency\"r\n\x13\x41pplyParametersResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x36\n\x0f\x65\x66\x66iciency_stat\x18\x03 \x01(\x0b\x32\x1d.prodvana.stat.EfficiencyStat\"\xf9\x01\n\x1bValidateApplyParametersResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x38\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\t\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\"Z\n\x18GetMaterializedConfigReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\xd3\x02\n\x19GetMaterializedConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x38\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12^\n\x10version_metadata\x18\x05 \x01(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\"A\n\x10\x44\x65leteServiceReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteServiceResp\"A\n\x0fListServicesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"?\n\x10ListServicesResp\x12+\n\x08services\x18\x01 \x03(\x0b\x32\x19.prodvana.service.Service\"G\n\rGetServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"<\n\x0eGetServiceResp\x12*\n\x07service\x18\x01 \x01(\x0b\x32\x19.prodvana.service.Service\"Q\n\x17ListServiceInstancesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"X\n\x18ListServiceInstancesResp\x12<\n\x11service_instances\x18\x01 \x03(\x0b\x32!.prodvana.service.ServiceInstance\"q\n\x15GetServiceInstanceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x16GetServiceInstanceResp\x12;\n\x10service_instance\x18\x01 \x01(\x0b\x32!.prodvana.service.ServiceInstance\"\xcc\x01\n\x14GetServiceMetricsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cinclude_cost\x18\x05 \x01(\x08\"~\n\x15GetServiceMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\x12$\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x16.prodvana.metrics.Cost\"O\n\x15GetServiceInsightsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"o\n\x0eListCommitsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"R\n\x0fListCommitsResp\x12&\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"F\n\x16GetServiceInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\xbd\x01\n\x17SnoozeServiceInsightReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\x05\x63lass\x18\x03 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1a\n\x18SnoozeServiceInsightResp\"O\n\x15GetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"Q\n\x16GetServiceMetadataResp\x12\x37\n\x08metadata\x18\x01 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadata\"\x92\x01\n\x15SetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x08metadata\x18\x03 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x18\n\x16SetServiceMetadataResp\"\x82\x01\n!ListMaterializedConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xad\x03\n\"ListMaterializedConfigVersionsResp\x12V\n\x08versions\x18\x01 \x03(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x95\x02\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\x12<\n\nparameters\x18\x04 \x01(\x0b\x32(.prodvana.service.ServiceParameterValues\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\xdb\x01\n\x13\x43onfigureServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0eservice_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"B\n\x14\x43onfigureServiceResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\"}\n\x1cListServiceConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xcd\x02\n\x1dListServiceConfigVersionsResp\x12Q\n\x08versions\x18\x01 \x03(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbf\x01\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"e\n\x13GetServiceConfigReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\"\xc1\x01\n\x14GetServiceConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\x12`\n\x17\x63onfig_version_metadata\x18\x03 \x01(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata2\xcb\x18\n\x0eServiceManager\x12\x95\x01\n\x10\x43onfigureService\x12%.prodvana.service.ConfigureServiceReq\x1a&.prodvana.service.ConfigureServiceResp\"2\x82\xd3\xe4\x93\x02,\"\'/v1/{application=*}/services/configure2:\x01*\x12\xbe\x01\n\x19ListServiceConfigVersions\x12..prodvana.service.ListServiceConfigVersionsReq\x1a/.prodvana.service.ListServiceConfigVersionsResp\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/{application=*}/services/{service=*}/config/versions\x12\x9a\x01\n\x10GetServiceConfig\x12%.prodvana.service.GetServiceConfigReq\x1a&.prodvana.service.GetServiceConfigResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/{application=*}/services/{service=*}/config\x12\x98\x01\n\x0f\x41pplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a%.prodvana.service.ApplyParametersResp\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/{application=*}/services/apply-parameters:\x01*\x12\xb1\x01\n\x17ValidateApplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a-.prodvana.service.ValidateApplyParametersResp\"A\x82\xd3\xe4\x93\x02;\"6/v1/{application=*}/services/apply-parameters/validate:\x01*\x12\xb6\x01\n\x15GetMaterializedConfig\x12*.prodvana.service.GetMaterializedConfigReq\x1a+.prodvana.service.GetMaterializedConfigResp\"D\x82\xd3\xe4\x93\x02>\x12</v1/{application=*}/services/{service=*}/materialized/config\x12\xda\x01\n\x1eListMaterializedConfigVersions\x12\x33.prodvana.service.ListMaterializedConfigVersionsReq\x1a\x34.prodvana.service.ListMaterializedConfigVersionsResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/{application=*}/services/{service=*}/materialized/config/versions\x12\x91\x01\n\rDeleteService\x12\".prodvana.service.DeleteServiceReq\x1a#.prodvana.service.DeleteServiceResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/{application=*}/services/{service=*}/delete\x12\x88\x01\n\x0cListServices\x12!.prodvana.service.ListServicesReq\x1a\".prodvana.service.ListServicesResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/applications/{application=*}/services\x12\x99\x01\n\x0bListCommits\x12 .prodvana.service.ListCommitsReq\x1a!.prodvana.service.ListCommitsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/commits\x12\x8e\x01\n\nGetService\x12\x1f.prodvana.service.GetServiceReq\x1a .prodvana.service.GetServiceResp\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/applications/{application=*}/services/{service=*}\x12\xbd\x01\n\x14ListServiceInstances\x12).prodvana.service.ListServiceInstancesReq\x1a*.prodvana.service.ListServiceInstancesResp\"N\x82\xd3\xe4\x93\x02H\x12\x46/v1/applications/{application=*}/services/{service=*}/release-channels\x12\xcb\x01\n\x12GetServiceInstance\x12\'.prodvana.service.GetServiceInstanceReq\x1a(.prodvana.service.GetServiceInstanceResp\"b\x82\xd3\xe4\x93\x02\\\x12Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}\x12\xab\x01\n\x11GetServiceMetrics\x12&.prodvana.service.GetServiceMetricsReq\x1a\'.prodvana.service.GetServiceMetricsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/metrics\x12\xaf\x01\n\x12GetServiceInsights\x12\'.prodvana.service.GetServiceInsightsReq\x1a(.prodvana.service.GetServiceInsightsResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/insights\x12\xbc\x01\n\x14SnoozeServiceInsight\x12).prodvana.service.SnoozeServiceInsightReq\x1a*.prodvana.service.SnoozeServiceInsightResp\"M\x82\xd3\xe4\x93\x02G\x1a\x45/v1/applications/{application=*}/services/{service=*}/insights/snooze\x12\xaf\x01\n\x12GetServiceMetadata\x12\'.prodvana.service.GetServiceMetadataReq\x1a(.prodvana.service.GetServiceMetadataResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/metadata\x12\xb2\x01\n\x12SetServiceMetadata\x12\'.prodvana.service.SetServiceMetadataReq\x1a(.prodvana.service.SetServiceMetadataResp\"I\x82\xd3\xe4\x93\x02\x43\">/v1/applications/{application=*}/services/{service=*}/metadata:\x01*BLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')



_SERVICECONFIGVERSIONREFERENCE = DESCRIPTOR.message_types_by_name['ServiceConfigVersionReference']
_APPLYPARAMETERSREQ = DESCRIPTOR.message_types_by_name['ApplyParametersReq']
_APPLYPARAMETERSREQ_PERRELEASECHANNEL = _APPLYPARAMETERSREQ.nested_types_by_name['PerReleaseChannel']
_APPLYPARAMETERSRESP = DESCRIPTOR.message_types_by_name['ApplyParametersResp']
_VALIDATEAPPLYPARAMETERSRESP = DESCRIPTOR.message_types_by_name['ValidateApplyParametersResp']
_GETMATERIALIZEDCONFIGREQ = DESCRIPTOR.message_types_by_name['GetMaterializedConfigReq']
_GETMATERIALIZEDCONFIGRESP = DESCRIPTOR.message_types_by_name['GetMaterializedConfigResp']
_DELETESERVICEREQ = DESCRIPTOR.message_types_by_name['DeleteServiceReq']
_DELETESERVICERESP = DESCRIPTOR.message_types_by_name['DeleteServiceResp']
_LISTSERVICESREQ = DESCRIPTOR.message_types_by_name['ListServicesReq']
_LISTSERVICESRESP = DESCRIPTOR.message_types_by_name['ListServicesResp']
_GETSERVICEREQ = DESCRIPTOR.message_types_by_name['GetServiceReq']
_GETSERVICERESP = DESCRIPTOR.message_types_by_name['GetServiceResp']
_LISTSERVICEINSTANCESREQ = DESCRIPTOR.message_types_by_name['ListServiceInstancesReq']
_LISTSERVICEINSTANCESRESP = DESCRIPTOR.message_types_by_name['ListServiceInstancesResp']
_GETSERVICEINSTANCEREQ = DESCRIPTOR.message_types_by_name['GetServiceInstanceReq']
_GETSERVICEINSTANCERESP = DESCRIPTOR.message_types_by_name['GetServiceInstanceResp']
_GETSERVICEMETRICSREQ = DESCRIPTOR.message_types_by_name['GetServiceMetricsReq']
_GETSERVICEMETRICSRESP = DESCRIPTOR.message_types_by_name['GetServiceMetricsResp']
_GETSERVICEINSIGHTSREQ = DESCRIPTOR.message_types_by_name['GetServiceInsightsReq']
_LISTCOMMITSREQ = DESCRIPTOR.message_types_by_name['ListCommitsReq']
_LISTCOMMITSRESP = DESCRIPTOR.message_types_by_name['ListCommitsResp']
_GETSERVICEINSIGHTSRESP = DESCRIPTOR.message_types_by_name['GetServiceInsightsResp']
_SNOOZESERVICEINSIGHTREQ = DESCRIPTOR.message_types_by_name['SnoozeServiceInsightReq']
_SNOOZESERVICEINSIGHTRESP = DESCRIPTOR.message_types_by_name['SnoozeServiceInsightResp']
_GETSERVICEMETADATAREQ = DESCRIPTOR.message_types_by_name['GetServiceMetadataReq']
_GETSERVICEMETADATARESP = DESCRIPTOR.message_types_by_name['GetServiceMetadataResp']
_SETSERVICEMETADATAREQ = DESCRIPTOR.message_types_by_name['SetServiceMetadataReq']
_SETSERVICEMETADATARESP = DESCRIPTOR.message_types_by_name['SetServiceMetadataResp']
_LISTMATERIALIZEDCONFIGVERSIONSREQ = DESCRIPTOR.message_types_by_name['ListMaterializedConfigVersionsReq']
_LISTMATERIALIZEDCONFIGVERSIONSRESP = DESCRIPTOR.message_types_by_name['ListMaterializedConfigVersionsResp']
_LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA = _LISTMATERIALIZEDCONFIGVERSIONSRESP.nested_types_by_name['VersionMetadata']
_CONFIGURESERVICEREQ = DESCRIPTOR.message_types_by_name['ConfigureServiceReq']
_CONFIGURESERVICERESP = DESCRIPTOR.message_types_by_name['ConfigureServiceResp']
_LISTSERVICECONFIGVERSIONSREQ = DESCRIPTOR.message_types_by_name['ListServiceConfigVersionsReq']
_LISTSERVICECONFIGVERSIONSRESP = DESCRIPTOR.message_types_by_name['ListServiceConfigVersionsResp']
_LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA = _LISTSERVICECONFIGVERSIONSRESP.nested_types_by_name['VersionMetadata']
_GETSERVICECONFIGREQ = DESCRIPTOR.message_types_by_name['GetServiceConfigReq']
_GETSERVICECONFIGRESP = DESCRIPTOR.message_types_by_name['GetServiceConfigResp']
ServiceConfigVersionReference = _reflection.GeneratedProtocolMessageType('ServiceConfigVersionReference', (_message.Message,), {
  'DESCRIPTOR' : _SERVICECONFIGVERSIONREFERENCE,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ServiceConfigVersionReference)
  })
_sym_db.RegisterMessage(ServiceConfigVersionReference)

ApplyParametersReq = _reflection.GeneratedProtocolMessageType('ApplyParametersReq', (_message.Message,), {

  'PerReleaseChannel' : _reflection.GeneratedProtocolMessageType('PerReleaseChannel', (_message.Message,), {
    'DESCRIPTOR' : _APPLYPARAMETERSREQ_PERRELEASECHANNEL,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersReq.PerReleaseChannel)
    })
  ,
  'DESCRIPTOR' : _APPLYPARAMETERSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersReq)
  })
_sym_db.RegisterMessage(ApplyParametersReq)
_sym_db.RegisterMessage(ApplyParametersReq.PerReleaseChannel)

ApplyParametersResp = _reflection.GeneratedProtocolMessageType('ApplyParametersResp', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPARAMETERSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersResp)
  })
_sym_db.RegisterMessage(ApplyParametersResp)

ValidateApplyParametersResp = _reflection.GeneratedProtocolMessageType('ValidateApplyParametersResp', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEAPPLYPARAMETERSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ValidateApplyParametersResp)
  })
_sym_db.RegisterMessage(ValidateApplyParametersResp)

GetMaterializedConfigReq = _reflection.GeneratedProtocolMessageType('GetMaterializedConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZEDCONFIGREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetMaterializedConfigReq)
  })
_sym_db.RegisterMessage(GetMaterializedConfigReq)

GetMaterializedConfigResp = _reflection.GeneratedProtocolMessageType('GetMaterializedConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZEDCONFIGRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetMaterializedConfigResp)
  })
_sym_db.RegisterMessage(GetMaterializedConfigResp)

DeleteServiceReq = _reflection.GeneratedProtocolMessageType('DeleteServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.DeleteServiceReq)
  })
_sym_db.RegisterMessage(DeleteServiceReq)

DeleteServiceResp = _reflection.GeneratedProtocolMessageType('DeleteServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.DeleteServiceResp)
  })
_sym_db.RegisterMessage(DeleteServiceResp)

ListServicesReq = _reflection.GeneratedProtocolMessageType('ListServicesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServicesReq)
  })
_sym_db.RegisterMessage(ListServicesReq)

ListServicesResp = _reflection.GeneratedProtocolMessageType('ListServicesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServicesResp)
  })
_sym_db.RegisterMessage(ListServicesResp)

GetServiceReq = _reflection.GeneratedProtocolMessageType('GetServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceReq)
  })
_sym_db.RegisterMessage(GetServiceReq)

GetServiceResp = _reflection.GeneratedProtocolMessageType('GetServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceResp)
  })
_sym_db.RegisterMessage(GetServiceResp)

ListServiceInstancesReq = _reflection.GeneratedProtocolMessageType('ListServiceInstancesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEINSTANCESREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceInstancesReq)
  })
_sym_db.RegisterMessage(ListServiceInstancesReq)

ListServiceInstancesResp = _reflection.GeneratedProtocolMessageType('ListServiceInstancesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEINSTANCESRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceInstancesResp)
  })
_sym_db.RegisterMessage(ListServiceInstancesResp)

GetServiceInstanceReq = _reflection.GeneratedProtocolMessageType('GetServiceInstanceReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSTANCEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInstanceReq)
  })
_sym_db.RegisterMessage(GetServiceInstanceReq)

GetServiceInstanceResp = _reflection.GeneratedProtocolMessageType('GetServiceInstanceResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSTANCERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInstanceResp)
  })
_sym_db.RegisterMessage(GetServiceInstanceResp)

GetServiceMetricsReq = _reflection.GeneratedProtocolMessageType('GetServiceMetricsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETRICSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetricsReq)
  })
_sym_db.RegisterMessage(GetServiceMetricsReq)

GetServiceMetricsResp = _reflection.GeneratedProtocolMessageType('GetServiceMetricsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETRICSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetricsResp)
  })
_sym_db.RegisterMessage(GetServiceMetricsResp)

GetServiceInsightsReq = _reflection.GeneratedProtocolMessageType('GetServiceInsightsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSIGHTSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInsightsReq)
  })
_sym_db.RegisterMessage(GetServiceInsightsReq)

ListCommitsReq = _reflection.GeneratedProtocolMessageType('ListCommitsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListCommitsReq)
  })
_sym_db.RegisterMessage(ListCommitsReq)

ListCommitsResp = _reflection.GeneratedProtocolMessageType('ListCommitsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListCommitsResp)
  })
_sym_db.RegisterMessage(ListCommitsResp)

GetServiceInsightsResp = _reflection.GeneratedProtocolMessageType('GetServiceInsightsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSIGHTSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInsightsResp)
  })
_sym_db.RegisterMessage(GetServiceInsightsResp)

SnoozeServiceInsightReq = _reflection.GeneratedProtocolMessageType('SnoozeServiceInsightReq', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZESERVICEINSIGHTREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SnoozeServiceInsightReq)
  })
_sym_db.RegisterMessage(SnoozeServiceInsightReq)

SnoozeServiceInsightResp = _reflection.GeneratedProtocolMessageType('SnoozeServiceInsightResp', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZESERVICEINSIGHTRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SnoozeServiceInsightResp)
  })
_sym_db.RegisterMessage(SnoozeServiceInsightResp)

GetServiceMetadataReq = _reflection.GeneratedProtocolMessageType('GetServiceMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETADATAREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetadataReq)
  })
_sym_db.RegisterMessage(GetServiceMetadataReq)

GetServiceMetadataResp = _reflection.GeneratedProtocolMessageType('GetServiceMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETADATARESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetadataResp)
  })
_sym_db.RegisterMessage(GetServiceMetadataResp)

SetServiceMetadataReq = _reflection.GeneratedProtocolMessageType('SetServiceMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVICEMETADATAREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SetServiceMetadataReq)
  })
_sym_db.RegisterMessage(SetServiceMetadataReq)

SetServiceMetadataResp = _reflection.GeneratedProtocolMessageType('SetServiceMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVICEMETADATARESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SetServiceMetadataResp)
  })
_sym_db.RegisterMessage(SetServiceMetadataResp)

ListMaterializedConfigVersionsReq = _reflection.GeneratedProtocolMessageType('ListMaterializedConfigVersionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsReq)
  })
_sym_db.RegisterMessage(ListMaterializedConfigVersionsReq)

ListMaterializedConfigVersionsResp = _reflection.GeneratedProtocolMessageType('ListMaterializedConfigVersionsResp', (_message.Message,), {

  'VersionMetadata' : _reflection.GeneratedProtocolMessageType('VersionMetadata', (_message.Message,), {
    'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata)
    })
  ,
  'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsResp)
  })
_sym_db.RegisterMessage(ListMaterializedConfigVersionsResp)
_sym_db.RegisterMessage(ListMaterializedConfigVersionsResp.VersionMetadata)

ConfigureServiceReq = _reflection.GeneratedProtocolMessageType('ConfigureServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURESERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ConfigureServiceReq)
  })
_sym_db.RegisterMessage(ConfigureServiceReq)

ConfigureServiceResp = _reflection.GeneratedProtocolMessageType('ConfigureServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURESERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ConfigureServiceResp)
  })
_sym_db.RegisterMessage(ConfigureServiceResp)

ListServiceConfigVersionsReq = _reflection.GeneratedProtocolMessageType('ListServiceConfigVersionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsReq)
  })
_sym_db.RegisterMessage(ListServiceConfigVersionsReq)

ListServiceConfigVersionsResp = _reflection.GeneratedProtocolMessageType('ListServiceConfigVersionsResp', (_message.Message,), {

  'VersionMetadata' : _reflection.GeneratedProtocolMessageType('VersionMetadata', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsResp.VersionMetadata)
    })
  ,
  'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsResp)
  })
_sym_db.RegisterMessage(ListServiceConfigVersionsResp)
_sym_db.RegisterMessage(ListServiceConfigVersionsResp.VersionMetadata)

GetServiceConfigReq = _reflection.GeneratedProtocolMessageType('GetServiceConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICECONFIGREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceConfigReq)
  })
_sym_db.RegisterMessage(GetServiceConfigReq)

GetServiceConfigResp = _reflection.GeneratedProtocolMessageType('GetServiceConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICECONFIGRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceConfigResp)
  })
_sym_db.RegisterMessage(GetServiceConfigResp)

_SERVICEMANAGER = DESCRIPTOR.services_by_name['ServiceManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._serialized_options = b'\372B\004r\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._options = None
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._options = None
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESERVICEREQ.fields_by_name['service']._options = None
  _DELETESERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICESREQ.fields_by_name['application']._options = None
  _LISTSERVICESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['application']._options = None
  _GETSERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['service']._options = None
  _GETSERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['application']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['service']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['application']._options = None
  _LISTCOMMITSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['service']._options = None
  _LISTCOMMITSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['application']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['application']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['service']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICEMANAGER.methods_by_name['ConfigureService']._options = None
  _SERVICEMANAGER.methods_by_name['ConfigureService']._serialized_options = b'\202\323\344\223\002,\"\'/v1/{application=*}/services/configure2:\001*'
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._serialized_options = b'\202\323\344\223\002:\0228/v1/{application=*}/services/{service=*}/config/versions'
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._serialized_options = b'\202\323\344\223\0021\022//v1/{application=*}/services/{service=*}/config'
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._serialized_options = b'\202\323\344\223\0022\"-/v1/{application=*}/services/apply-parameters:\001*'
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._serialized_options = b'\202\323\344\223\002;\"6/v1/{application=*}/services/apply-parameters/validate:\001*'
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._serialized_options = b'\202\323\344\223\002>\022</v1/{application=*}/services/{service=*}/materialized/config'
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._serialized_options = b'\202\323\344\223\002G\022E/v1/{application=*}/services/{service=*}/materialized/config/versions'
  _SERVICEMANAGER.methods_by_name['DeleteService']._options = None
  _SERVICEMANAGER.methods_by_name['DeleteService']._serialized_options = b'\202\323\344\223\0021*//v1/{application=*}/services/{service=*}/delete'
  _SERVICEMANAGER.methods_by_name['ListServices']._options = None
  _SERVICEMANAGER.methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002+\022)/v1/applications/{application=*}/services'
  _SERVICEMANAGER.methods_by_name['ListCommits']._options = None
  _SERVICEMANAGER.methods_by_name['ListCommits']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/commits'
  _SERVICEMANAGER.methods_by_name['GetService']._options = None
  _SERVICEMANAGER.methods_by_name['GetService']._serialized_options = b'\202\323\344\223\0027\0225/v1/applications/{application=*}/services/{service=*}'
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._serialized_options = b'\202\323\344\223\002H\022F/v1/applications/{application=*}/services/{service=*}/release-channels'
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._serialized_options = b'\202\323\344\223\002\\\022Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}'
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/metrics'
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/insights'
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._options = None
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._serialized_options = b'\202\323\344\223\002G\032E/v1/applications/{application=*}/services/{service=*}/insights/snooze'
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/metadata'
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._serialized_options = b'\202\323\344\223\002C\">/v1/applications/{application=*}/services/{service=*}/metadata:\001*'
  _SERVICECONFIGVERSIONREFERENCE._serialized_start=528
  _SERVICECONFIGVERSIONREFERENCE._serialized_end=647
  _APPLYPARAMETERSREQ._serialized_start=650
  _APPLYPARAMETERSREQ._serialized_end=1343
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL._serialized_start=1151
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL._serialized_end=1279
  _APPLYPARAMETERSRESP._serialized_start=1345
  _APPLYPARAMETERSRESP._serialized_end=1459
  _VALIDATEAPPLYPARAMETERSRESP._serialized_start=1462
  _VALIDATEAPPLYPARAMETERSRESP._serialized_end=1711
  _GETMATERIALIZEDCONFIGREQ._serialized_start=1713
  _GETMATERIALIZEDCONFIGREQ._serialized_end=1803
  _GETMATERIALIZEDCONFIGRESP._serialized_start=1806
  _GETMATERIALIZEDCONFIGRESP._serialized_end=2145
  _DELETESERVICEREQ._serialized_start=2147
  _DELETESERVICEREQ._serialized_end=2212
  _DELETESERVICERESP._serialized_start=2214
  _DELETESERVICERESP._serialized_end=2233
  _LISTSERVICESREQ._serialized_start=2235
  _LISTSERVICESREQ._serialized_end=2300
  _LISTSERVICESRESP._serialized_start=2302
  _LISTSERVICESRESP._serialized_end=2365
  _GETSERVICEREQ._serialized_start=2367
  _GETSERVICEREQ._serialized_end=2438
  _GETSERVICERESP._serialized_start=2440
  _GETSERVICERESP._serialized_end=2500
  _LISTSERVICEINSTANCESREQ._serialized_start=2502
  _LISTSERVICEINSTANCESREQ._serialized_end=2583
  _LISTSERVICEINSTANCESRESP._serialized_start=2585
  _LISTSERVICEINSTANCESRESP._serialized_end=2673
  _GETSERVICEINSTANCEREQ._serialized_start=2675
  _GETSERVICEINSTANCEREQ._serialized_end=2788
  _GETSERVICEINSTANCERESP._serialized_start=2790
  _GETSERVICEINSTANCERESP._serialized_end=2875
  _GETSERVICEMETRICSREQ._serialized_start=2878
  _GETSERVICEMETRICSREQ._serialized_end=3082
  _GETSERVICEMETRICSRESP._serialized_start=3084
  _GETSERVICEMETRICSRESP._serialized_end=3210
  _GETSERVICEINSIGHTSREQ._serialized_start=3212
  _GETSERVICEINSIGHTSREQ._serialized_end=3291
  _LISTCOMMITSREQ._serialized_start=3293
  _LISTCOMMITSREQ._serialized_end=3404
  _LISTCOMMITSRESP._serialized_start=3406
  _LISTCOMMITSRESP._serialized_end=3488
  _GETSERVICEINSIGHTSRESP._serialized_start=3490
  _GETSERVICEINSIGHTSRESP._serialized_end=3560
  _SNOOZESERVICEINSIGHTREQ._serialized_start=3563
  _SNOOZESERVICEINSIGHTREQ._serialized_end=3752
  _SNOOZESERVICEINSIGHTRESP._serialized_start=3754
  _SNOOZESERVICEINSIGHTRESP._serialized_end=3780
  _GETSERVICEMETADATAREQ._serialized_start=3782
  _GETSERVICEMETADATAREQ._serialized_end=3861
  _GETSERVICEMETADATARESP._serialized_start=3863
  _GETSERVICEMETADATARESP._serialized_end=3944
  _SETSERVICEMETADATAREQ._serialized_start=3947
  _SETSERVICEMETADATAREQ._serialized_end=4093
  _SETSERVICEMETADATARESP._serialized_start=4095
  _SETSERVICEMETADATARESP._serialized_end=4119
  _LISTMATERIALIZEDCONFIGVERSIONSREQ._serialized_start=4122
  _LISTMATERIALIZEDCONFIGVERSIONSREQ._serialized_end=4252
  _LISTMATERIALIZEDCONFIGVERSIONSRESP._serialized_start=4255
  _LISTMATERIALIZEDCONFIGVERSIONSRESP._serialized_end=4684
  _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA._serialized_start=4407
  _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA._serialized_end=4684
  _CONFIGURESERVICEREQ._serialized_start=4687
  _CONFIGURESERVICEREQ._serialized_end=4906
  _CONFIGURESERVICERESP._serialized_start=4908
  _CONFIGURESERVICERESP._serialized_end=4974
  _LISTSERVICECONFIGVERSIONSREQ._serialized_start=4976
  _LISTSERVICECONFIGVERSIONSREQ._serialized_end=5101
  _LISTSERVICECONFIGVERSIONSRESP._serialized_start=5104
  _LISTSERVICECONFIGVERSIONSRESP._serialized_end=5437
  _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA._serialized_start=5246
  _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA._serialized_end=5437
  _GETSERVICECONFIGREQ._serialized_start=5439
  _GETSERVICECONFIGREQ._serialized_end=5540
  _GETSERVICECONFIGRESP._serialized_start=5543
  _GETSERVICECONFIGRESP._serialized_end=5736
  _SERVICEMANAGER._serialized_start=5739
  _SERVICEMANAGER._serialized_end=8886
# @@protoc_insertion_point(module_scope)
