# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#prodvana/environment/clusters.proto\x12\x14prodvana.environment\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a prodvana/common_config/env.proto\x1a!prodvana/common_config/task.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a\'prodvana/runtimes/runtimes_config.proto\"\xfd\x03\n\x0b\x43lusterAuth\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_cert\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x17\n\x0fservice_account\x18\x04 \x01(\t\x12\x38\n\x03\x65\x63s\x18\x05 \x01(\x0b\x32).prodvana.environment.ClusterAuth.ECSAuthH\x00\x12\x38\n\x03k8s\x18\x08 \x01(\x0b\x32).prodvana.environment.ClusterAuth.K8sAuthH\x00\x12\x16\n\x0ek8s_agent_auth\x18\x06 \x01(\x08\x1ao\n\x07\x45\x43SAuth\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x17\n\x0f\x61ssume_role_arn\x18\x04 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x05 \x01(\t\x1a\x86\x01\n\x07K8sAuth\x12J\n\tagent_env\x18\x01 \x03(\x0b\x32\x37.prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry\x1a/\n\rAgentEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nauth_oneofJ\x04\x08\x07\x10\x08R\textension\"\xe9\x02\n\x07\x43luster\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x34\n\x06origin\x18\x03 \x01(\x0e\x32$.prodvana.environment.Cluster.Origin\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x05 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\x06 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x18last_heartbeat_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06Origin\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08PRODVANA\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xc6\x01\n\x11\x46\x61keClusterConfig\x12Z\n\x11\x63rashing_programs\x18\x01 \x03(\x0b\x32?.prodvana.environment.FakeClusterConfig.CrashingProgramPatterns\x1aU\n\x17\x43rashingProgramPatterns\x12\x13\n\x0bimage_regex\x18\x01 \x01(\t\x12\x11\n\tcmd_regex\x18\x02 \x01(\t\x12\x12\n\nlog_output\x18\x03 \x01(\t\"\x86\x02\n\x10\x45xtensionCommand\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x30\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\xac\x02\n\x16\x45xtensionClusterConfig\x12?\n\x05\x61pply\x18\x01 \x01(\x0b\x32&.prodvana.environment.ExtensionCommandB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x05\x66\x65tch\x18\x02 \x01(\x0b\x32&.prodvana.environment.ExtensionCommand\x12N\n\nparameters\x18\x03 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12J\n\rproxy_runtime\x18\x04 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xc2\x02\n\x18\x43ompiledExtensionCommand\x12\x13\n\x0bname_prefix\x18\x01 \x01(\t\x12\x37\n\x07\x63ommand\x18\x02 \x01(\x0b\x32&.prodvana.environment.ExtensionCommand\x12\x44\n\x11runtime_execution\x18\x03 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12\x44\n\x03\x65nv\x18\x04 \x03(\x0b\x32\x37.prodvana.environment.CompiledExtensionCommand.EnvEntry\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"\xc0\x0c\n\rClusterConfig\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x17\n\x0f\x64isable_flagger\x18\x01 \x01(\x08\x12\x15\n\rdisable_istio\x18\x02 \x01(\x08\x12>\n\x08kubecost\x18\x03 \x01(\x0b\x32,.prodvana.environment.ClusterConfig.Kubecost\x12<\n\x07\x64\x61tadog\x18\x04 \x01(\x0b\x32+.prodvana.environment.ClusterConfig.Datadog\x12\x43\n\x0b\x61lb_ingress\x18\x06 \x01(\x0b\x32..prodvana.environment.ClusterConfig.ALBIngress\x12G\n\rargo_rollouts\x18\x07 \x01(\x0b\x32\x30.prodvana.environment.ClusterConfig.ArgoRollouts\x12\x43\n\x0bgke_ingress\x18\x08 \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12P\n\x18self_managed_gke_ingress\x18\x0b \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12I\n\x0e\x63loud_provider\x18\t \x01(\x0e\x32\x31.prodvana.environment.ClusterConfig.CloudProvider\x12\x37\n\x04\x66\x61ke\x18\n \x01(\x0b\x32\'.prodvana.environment.FakeClusterConfigH\x00\x12\x41\n\textension\x18\x0c \x01(\x0b\x32,.prodvana.environment.ExtensionClusterConfigH\x00\x1aH\n\x08Kubecost\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x1a\n\x12kubecost_namespace\x18\x03 \x01(\t\x1a\x65\n\x07\x44\x61tadog\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x61tadog_namespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x0c\n\x04site\x18\x05 \x01(\t\x1a\x62\n\nALBIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1e\n\ringress_class\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x1b\x64\x65\x66\x61ult_balancer_attributes\x18\x03 \x03(\t\x1a\xba\x03\n\x0c\x41rgoRollouts\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12T\n\ttemplates\x18\x02 \x03(\x0b\x32\x41.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate\x1a\xc2\x02\n\x10\x41nalysisTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x66\n\x0b\x61rg_mapping\x18\x02 \x03(\x0b\x32Q.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry\x1a}\n\x0f\x41rgMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Y\n\x05value\x18\x02 \x01(\x0e\x32J.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue:\x02\x38\x01\"9\n\x08\x41rgValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x13\n\x0fRELEASE_CHANNEL\x10\x02\x1a\x37\n\nGKEIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x63ontainer_native\x18\x02 \x01(\x08\"T\n\rCloudProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x45KS\x10\x01\x12\x07\n\x03GKE\x10\x02\x12\x07\n\x03\x41KS\x10\x03\x12\n\n\x06ONPREM\x10\x04\x12\x0f\n\x0bOTHER_CLOUD\x10\x05\x42\x0f\n\rcluster_oneofJ\x04\x08\x05\x10\x06R\x0f\x61ws_alb_ingress*E\n\x0b\x43lusterType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03K8S\x10\x01\x12\x07\n\x03\x45\x43S\x10\x02\x12\x08\n\x04\x46\x41KE\x10\x03\x12\r\n\tEXTENSION\x10\x04\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_CLUSTERTYPE = DESCRIPTOR.enum_types_by_name['ClusterType']
ClusterType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTYPE)
UNKNOWN = 0
K8S = 1
ECS = 2
FAKE = 3
EXTENSION = 4


_CLUSTERAUTH = DESCRIPTOR.message_types_by_name['ClusterAuth']
_CLUSTERAUTH_ECSAUTH = _CLUSTERAUTH.nested_types_by_name['ECSAuth']
_CLUSTERAUTH_K8SAUTH = _CLUSTERAUTH.nested_types_by_name['K8sAuth']
_CLUSTERAUTH_K8SAUTH_AGENTENVENTRY = _CLUSTERAUTH_K8SAUTH.nested_types_by_name['AgentEnvEntry']
_CLUSTER = DESCRIPTOR.message_types_by_name['Cluster']
_FAKECLUSTERCONFIG = DESCRIPTOR.message_types_by_name['FakeClusterConfig']
_FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS = _FAKECLUSTERCONFIG.nested_types_by_name['CrashingProgramPatterns']
_EXTENSIONCOMMAND = DESCRIPTOR.message_types_by_name['ExtensionCommand']
_EXTENSIONCLUSTERCONFIG = DESCRIPTOR.message_types_by_name['ExtensionClusterConfig']
_COMPILEDEXTENSIONCOMMAND = DESCRIPTOR.message_types_by_name['CompiledExtensionCommand']
_COMPILEDEXTENSIONCOMMAND_ENVENTRY = _COMPILEDEXTENSIONCOMMAND.nested_types_by_name['EnvEntry']
_CLUSTERCONFIG = DESCRIPTOR.message_types_by_name['ClusterConfig']
_CLUSTERCONFIG_KUBECOST = _CLUSTERCONFIG.nested_types_by_name['Kubecost']
_CLUSTERCONFIG_DATADOG = _CLUSTERCONFIG.nested_types_by_name['Datadog']
_CLUSTERCONFIG_ALBINGRESS = _CLUSTERCONFIG.nested_types_by_name['ALBIngress']
_CLUSTERCONFIG_ARGOROLLOUTS = _CLUSTERCONFIG.nested_types_by_name['ArgoRollouts']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE = _CLUSTERCONFIG_ARGOROLLOUTS.nested_types_by_name['AnalysisTemplate']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.nested_types_by_name['ArgMappingEntry']
_CLUSTERCONFIG_GKEINGRESS = _CLUSTERCONFIG.nested_types_by_name['GKEIngress']
_CLUSTER_ORIGIN = _CLUSTER.enum_types_by_name['Origin']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.enum_types_by_name['ArgValue']
_CLUSTERCONFIG_CLOUDPROVIDER = _CLUSTERCONFIG.enum_types_by_name['CloudProvider']
ClusterAuth = _reflection.GeneratedProtocolMessageType('ClusterAuth', (_message.Message,), {

  'ECSAuth' : _reflection.GeneratedProtocolMessageType('ECSAuth', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERAUTH_ECSAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.ECSAuth)
    })
  ,

  'K8sAuth' : _reflection.GeneratedProtocolMessageType('K8sAuth', (_message.Message,), {

    'AgentEnvEntry' : _reflection.GeneratedProtocolMessageType('AgentEnvEntry', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry)
      })
    ,
    'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth)
    })
  ,
  'DESCRIPTOR' : _CLUSTERAUTH,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth)
  })
_sym_db.RegisterMessage(ClusterAuth)
_sym_db.RegisterMessage(ClusterAuth.ECSAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth.AgentEnvEntry)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

FakeClusterConfig = _reflection.GeneratedProtocolMessageType('FakeClusterConfig', (_message.Message,), {

  'CrashingProgramPatterns' : _reflection.GeneratedProtocolMessageType('CrashingProgramPatterns', (_message.Message,), {
    'DESCRIPTOR' : _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig.CrashingProgramPatterns)
    })
  ,
  'DESCRIPTOR' : _FAKECLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig)
  })
_sym_db.RegisterMessage(FakeClusterConfig)
_sym_db.RegisterMessage(FakeClusterConfig.CrashingProgramPatterns)

ExtensionCommand = _reflection.GeneratedProtocolMessageType('ExtensionCommand', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONCOMMAND,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ExtensionCommand)
  })
_sym_db.RegisterMessage(ExtensionCommand)

ExtensionClusterConfig = _reflection.GeneratedProtocolMessageType('ExtensionClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONCLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ExtensionClusterConfig)
  })
_sym_db.RegisterMessage(ExtensionClusterConfig)

CompiledExtensionCommand = _reflection.GeneratedProtocolMessageType('CompiledExtensionCommand', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPILEDEXTENSIONCOMMAND_ENVENTRY,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.CompiledExtensionCommand.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _COMPILEDEXTENSIONCOMMAND,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.CompiledExtensionCommand)
  })
_sym_db.RegisterMessage(CompiledExtensionCommand)
_sym_db.RegisterMessage(CompiledExtensionCommand.EnvEntry)

ClusterConfig = _reflection.GeneratedProtocolMessageType('ClusterConfig', (_message.Message,), {

  'Kubecost' : _reflection.GeneratedProtocolMessageType('Kubecost', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_KUBECOST,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Kubecost)
    })
  ,

  'Datadog' : _reflection.GeneratedProtocolMessageType('Datadog', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_DATADOG,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Datadog)
    })
  ,

  'ALBIngress' : _reflection.GeneratedProtocolMessageType('ALBIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_ALBINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ALBIngress)
    })
  ,

  'ArgoRollouts' : _reflection.GeneratedProtocolMessageType('ArgoRollouts', (_message.Message,), {

    'AnalysisTemplate' : _reflection.GeneratedProtocolMessageType('AnalysisTemplate', (_message.Message,), {

      'ArgMappingEntry' : _reflection.GeneratedProtocolMessageType('ArgMappingEntry', (_message.Message,), {
        'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY,
        '__module__' : 'prodvana.environment.clusters_pb2'
        # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
        })
      ,
      'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate)
      })
    ,
    'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts)
    })
  ,

  'GKEIngress' : _reflection.GeneratedProtocolMessageType('GKEIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_GKEINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.GKEIngress)
    })
  ,
  'DESCRIPTOR' : _CLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig)
  })
_sym_db.RegisterMessage(ClusterConfig)
_sym_db.RegisterMessage(ClusterConfig.Kubecost)
_sym_db.RegisterMessage(ClusterConfig.Datadog)
_sym_db.RegisterMessage(ClusterConfig.ALBIngress)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
_sym_db.RegisterMessage(ClusterConfig.GKEIngress)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._options = None
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_options = b'8\001'
  _EXTENSIONCOMMAND.oneofs_by_name['exec_config']._options = None
  _EXTENSIONCOMMAND.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._options = None
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._options = None
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._options = None
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_options = b'8\001'
  _CLUSTERTYPE._serialized_start=3923
  _CLUSTERTYPE._serialized_end=3992
  _CLUSTERAUTH._serialized_start=351
  _CLUSTERAUTH._serialized_end=860
  _CLUSTERAUTH_ECSAUTH._serialized_start=581
  _CLUSTERAUTH_ECSAUTH._serialized_end=692
  _CLUSTERAUTH_K8SAUTH._serialized_start=695
  _CLUSTERAUTH_K8SAUTH._serialized_end=829
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_start=782
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_end=829
  _CLUSTER._serialized_start=863
  _CLUSTER._serialized_end=1224
  _CLUSTER_ORIGIN._serialized_start=1175
  _CLUSTER_ORIGIN._serialized_end=1224
  _FAKECLUSTERCONFIG._serialized_start=1227
  _FAKECLUSTERCONFIG._serialized_end=1425
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_start=1340
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_end=1425
  _EXTENSIONCOMMAND._serialized_start=1428
  _EXTENSIONCOMMAND._serialized_end=1690
  _EXTENSIONCLUSTERCONFIG._serialized_start=1693
  _EXTENSIONCLUSTERCONFIG._serialized_end=1993
  _COMPILEDEXTENSIONCOMMAND._serialized_start=1996
  _COMPILEDEXTENSIONCOMMAND._serialized_end=2318
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_start=2242
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_end=2318
  _CLUSTERCONFIG._serialized_start=2321
  _CLUSTERCONFIG._serialized_end=3921
  _CLUSTERCONFIG_KUBECOST._serialized_start=3018
  _CLUSTERCONFIG_KUBECOST._serialized_end=3090
  _CLUSTERCONFIG_DATADOG._serialized_start=3092
  _CLUSTERCONFIG_DATADOG._serialized_end=3193
  _CLUSTERCONFIG_ALBINGRESS._serialized_start=3195
  _CLUSTERCONFIG_ALBINGRESS._serialized_end=3293
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_start=3296
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_end=3738
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_start=3416
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_end=3738
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_start=3554
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_end=3679
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_start=3681
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_end=3738
  _CLUSTERCONFIG_GKEINGRESS._serialized_start=3740
  _CLUSTERCONFIG_GKEINGRESS._serialized_end=3795
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_start=3797
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_end=3881
# @@protoc_insertion_point(module_scope)
