# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/repo/repo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18prodvana/repo/repo.proto\x12\rprodvana.repo\"#\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"^\n\x06\x43ommit\x12\x11\n\tcommit_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\x13.prodvana.repo.User\"1\n\x0b\x46uzzyCommit\x12\x12\n\ncommit_ish\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\tBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repob\x06proto3')



_USER = DESCRIPTOR.message_types_by_name['User']
_COMMIT = DESCRIPTOR.message_types_by_name['Commit']
_FUZZYCOMMIT = DESCRIPTOR.message_types_by_name['FuzzyCommit']
User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.User)
  })
_sym_db.RegisterMessage(User)

Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), {
  'DESCRIPTOR' : _COMMIT,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.Commit)
  })
_sym_db.RegisterMessage(Commit)

FuzzyCommit = _reflection.GeneratedProtocolMessageType('FuzzyCommit', (_message.Message,), {
  'DESCRIPTOR' : _FUZZYCOMMIT,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.FuzzyCommit)
  })
_sym_db.RegisterMessage(FuzzyCommit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repo'
  _USER._serialized_start=43
  _USER._serialized_end=78
  _COMMIT._serialized_start=80
  _COMMIT._serialized_end=174
  _FUZZYCOMMIT._serialized_start=176
  _FUZZYCOMMIT._serialized_end=225
# @@protoc_insertion_point(module_scope)
